pub struct CreateNamespace {
pub namespace: Pubkey,
pub authority: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for CreateNamespace.
Fields
namespace: PubkeyCHECK: This is not dangerous because we don’t read or write from this account
payer: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateNamespacewhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateNamespacewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateNamespace
impl ToAccountMetas for CreateNamespace
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateNamespace
impl RefUnwindSafe for CreateNamespace
impl Send for CreateNamespace
impl Sync for CreateNamespace
impl Unpin for CreateNamespace
impl UnwindSafe for CreateNamespace