Struct namespaces::state::ClaimRequest
source · [−]pub struct ClaimRequest {
pub bump: u8,
pub requestor: Pubkey,
pub is_approved: bool,
pub namespace: Pubkey,
pub entry_name: String,
pub counter: u32,
}Fields
bump: u8requestor: Pubkeyis_approved: boolnamespace: Pubkeyentry_name: Stringcounter: u32Trait Implementations
sourceimpl AccountDeserialize for ClaimRequest
impl AccountDeserialize for ClaimRequest
sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a Mint account into a token
Account. Read more
sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator. This should only be used on account initialization, when the bytes of the account are zeroed. Read more
sourceimpl AccountSerialize for ClaimRequest
impl AccountSerialize for ClaimRequest
sourceimpl BorshDeserialize for ClaimRequest where
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
bool: BorshDeserialize,
Pubkey: BorshDeserialize,
String: BorshDeserialize,
u32: BorshDeserialize,
impl BorshDeserialize for ClaimRequest where
u8: BorshDeserialize,
Pubkey: BorshDeserialize,
bool: BorshDeserialize,
Pubkey: BorshDeserialize,
String: BorshDeserialize,
u32: BorshDeserialize,
sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes. Updates the buffer to point at the remaining bytes. Read more
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
sourceimpl BorshSerialize for ClaimRequest where
u8: BorshSerialize,
Pubkey: BorshSerialize,
bool: BorshSerialize,
Pubkey: BorshSerialize,
String: BorshSerialize,
u32: BorshSerialize,
impl BorshSerialize for ClaimRequest where
u8: BorshSerialize,
Pubkey: BorshSerialize,
bool: BorshSerialize,
Pubkey: BorshSerialize,
String: BorshSerialize,
u32: BorshSerialize,
sourceimpl Clone for ClaimRequest
impl Clone for ClaimRequest
sourcefn clone(&self) -> ClaimRequest
fn clone(&self) -> ClaimRequest
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Discriminator for ClaimRequest
impl Discriminator for ClaimRequest
fn discriminator() -> [u8; 8]
sourceimpl Owner for ClaimRequest
impl Owner for ClaimRequest